@@ -2,11 +2,8 @@ import argparse
 import itertools
 import os
 import sys
-from difflib import SequenceMatcher
 from pathlib import Path
 
-import jellyfish
-import Levenshtein  # type: ignore
 import numpy as np
 import pandas as pd  # type: ignore
 from lxml import etree  # type: ignore
@@ -26,11 +23,10 @@ def parse_xml(path: Path):
         root = tree.getroot()
         if int(root.find("testsuite").attrib["failures"]) > 0:
             for node in root.findall(".//failure"):
-                rf_support = node.attrib.get("type")
-                if rf_support:
-                    failure.append(node.attrib["message"])
-                else:
+                if node.text:
                     failure.append(node.text)
+                else:
+                    failure.append(node.attrib["message"])
                 parent = node.getparent()
                 testname.append(parent.attrib["name"])
                 classname.append(parent.attrib["classname"])
@@ -39,12 +35,6 @@ def parse_xml(path: Path):
     return failure, testname, filename, classname
 
 
-def jaccard_similarity(list1, list2):
-    s1 = set(list1)
-    s2 = set(list2)
-    return float(len(s1.intersection(s2)) / len(s1.union(s2)))
-
-
 def cosine_sim_vectors(vec1, vec2):
     """Takes in 2 vectors and returns a cosine similiarity between two vectors."""
     vec1 = vec1.reshape(1, -1)
@@ -53,42 +43,19 @@ def cosine_sim_vectors(vec1, vec2):
 
 
 def score_failures(failures):
-    """takes in a list of tuples of failures and returns 5 lists of 5 different string similiarity algorithms.
+    """takes in a list of tuples of failures and returns a lists of cosine similarity.
 
-    sm_ratios, list of similiarity scores between two items in a tuple
     coss, a list of cosine similiarity scores between two items in a tuple
-    jaccards, a list of jaccard scores between two items in a tuple
-    jaros, a list of jaro scores between two items in a tuple
-    levens, a list of levenshtein ratio scores between two items in a tuple
     """
-    sm_ratios = []
     coss = []
-    jaccards = []
-    jaros = []
-    levens = []
-
     for failure in failures:
         str1 = failure[0]
         str2 = failure[1]
-
-        sm = SequenceMatcher(a=str1, b=str2)
-        sm_ratios.append(sm.ratio())
-
         vectorizer = CountVectorizer().fit_transform([str1, str2])
         vectors = vectorizer.toarray()
         cos = cosine_sim_vectors(vectors[0], vectors[1])
         coss.append(cos)
-
-        jaccard = jaccard_similarity(str1, str2)
-        jaccards.append(jaccard)
-
-        jaro = jellyfish.jaro_similarity(str1, str2)
-        jaros.append(jaro)
-
-        leven = Levenshtein.ratio(str1, str2)
-        levens.append(leven)
-
-    return sm_ratios, coss, jaccards, jaros, levens
+    return coss
 
 
 def run(path: str):
@@ -105,18 +72,13 @@ def run(path: str):
     failures = list(itertools.permutations(failure, 2))
     filenames = list(itertools.permutations(filename, 2))
     classnames = list(itertools.permutations(classname, 2))
-
-    sm_ratios, coss, jaccards, jaros, levens = score_failures(failures)
+    coss = score_failures(failures)
 
     items = [
         filenames,
         testnames,
         classnames,
-        sm_ratios,
         coss,
-        jaccards,
-        jaros,
-        levens,
         failures,
     ]
 
@@ -133,15 +95,11 @@ def run(path: str):
         "testname2",
         "suitename1",
         "suitename2",
-        "sm_ratio",
         "cos",
-        "jaccard",
-        "jaro",
-        "leven",
         "failure1",
         "failure2",
     ]
-    df = df[["failure1", "suitename2", "testname2", "filename2", "cos", "leven"]]
+    df = df[["failure1", "suitename2", "testname2", "filename2", "cos"]]
     for failure in np.unique(df["failure1"].values):
         print("============== FAILURE START =================")
         print(failure)
